/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        initialization_service.c
 * Dependencies:    See INCLUDES section below
 * Processor:       dsPIC33
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:
*/

//Includes
//Include all headers for any enabled TCPIP Stack functions
#include "TCPIP Stack/TCPIP.h"

#if defined(STACK_USE_ZEROCONF_LINK_LOCAL)
	#include "TCPIP Stack/ZeroconfLinkLocal.h"
#endif	//#if defined(STACK_USE_ZEROCONF_LINK_LOCAL)

#if defined(STACK_USE_ZEROCONF_MDNS_SD)
	#include "TCPIP Stack/ZeroconfMulticastDNS.h"
#endif	//#if defined(STACK_USE_ZEROCONF_MDNS_SD)

#include "include files.h"


//Fuses


//Variables


//Private Prototypes
 

//Declarations


#if defined(WF_CS_TRIS)
	/******************************************************************************
	 Function:        	void WF_Connect (void)
	 Precondition:    	None
	 Input:           	None
	 Output:         	None
	 Side Effects:    	None
	 Description:       Connects to an 802.11 network.  Customize this function as needed 
						for your application.
	 *****************************************************************************/
	void WF_Connect(void)
	{
	    UINT8 ConnectionProfileID;
	    UINT8 channelList[] = MY_DEFAULT_CHANNEL_LIST;
	    
	    /* create a Connection Profile */
	    WF_CPCreate(&ConnectionProfileID);
	
	    #if defined(STACK_USE_UART)
		    putrsUART("Set SSID (");
		    putsUART(AppConfig.MySSID);
		    putrsUART(")\r\n");
	    #endif	//#if defined(STACK_USE_UART)
	    WF_CPSetSsid(ConnectionProfileID, 
	                 AppConfig.MySSID, 
	                 AppConfig.SsidLength);
	
	    #if defined(STACK_USE_UART)
		    putrsUART("Set Network Type\r\n");
		#endif	//#if defined(STACK_USE_UART)
	    WF_CPSetNetworkType(ConnectionProfileID, MY_DEFAULT_NETWORK_TYPE);
	    
		#if defined(STACK_USE_UART)
			putrsUART("Set Scan Type\r\n");
		#endif	//#if defined(STACK_USE_UART)
	    WF_CASetScanType(MY_DEFAULT_SCAN_TYPE);
	    
	    #if defined(STACK_USE_UART)
	    	putrsUART("Set Channel List\r\n");
	    #endif 	//   #if defined(STACK_USE_UART)
	    WF_CASetChannelList(channelList, sizeof(channelList));
	    
	    #if defined(STACK_USE_UART)
	    	putrsUART("Set list retry count\r\n");
	    #endif	//#if defined(STACK_USE_UART)
	    // The Retry Count parameter tells the WiFi Connection manager how many attempts to make when trying
	    // to connect to an existing network.  In the Infrastructure case, the default is to retry forever so that
	    // if the AP is turned off or out of range, the radio will continue to attempt a connection until the
	    // AP is eventually back on or in range.  In the Adhoc case, the default is to retry 3 times since the 
	    // purpose of attempting to establish a network in the Adhoc case is only to verify that one does not
	    // initially exist.  If the retry count was set to WF_RETRY_FOREVER in the AdHoc mode, an AdHoc network
	    // would never be established.  The constants MY_DEFAULT_LIST_RETRY_COUNT_ADHOC and 
	    // MY_DEFAULT_LIST_RETRY_COUNT_INFRASTRUCTURE have been created specifically for the June 2011 MAL release.
	    #if defined(EZ_CONFIG_STORE)
	        if (AppConfig.networkType == WF_ADHOC)
	            WF_CASetListRetryCount(MY_DEFAULT_LIST_RETRY_COUNT_ADHOC);
	        else
	            WF_CASetListRetryCount(MY_DEFAULT_LIST_RETRY_COUNT_INFRASTRUCTURE);
	    #else
	        #if (MY_DEFAULT_NETWORK_TYPE == WF_ADHOC)
	            WF_CASetListRetryCount(MY_DEFAULT_LIST_RETRY_COUNT_ADHOC);
	        #else
	            WF_CASetListRetryCount(MY_DEFAULT_LIST_RETRY_COUNT_INFRASTRUCTURE);
	        #endif
	    #endif	//#if defined(EZ_CONFIG_STORE)
	    
	
	    #if defined(STACK_USE_UART)        
		    putrsUART("Set Event Notify\r\n");    
	    #endif	//#if defined(STACK_USE_UART)
	    WF_CASetEventNotificationAction(MY_DEFAULT_EVENT_NOTIFICATION_LIST);
	    
	    #if defined(STACK_USE_UART)
		    putrsUART("Set Beacon Timeout\r\n");
	    #endif	//#if defined(STACK_USE_UART)
	    WF_CASetBeaconTimeout(40);
	    
	    /* Set Security */
	    #if (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_OPEN)
	        #if defined(STACK_USE_UART)
	        	putrsUART("Set Security (Open)\r\n");
	        #endif	//#if defined(STACK_USE_UART)
	    #elif (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WEP_40)
	        #if defined(STACK_USE_UART)
	        	putrsUART("Set Security (WEP40)\r\n");
	        #endif	//#if defined(STACK_USE_UART)
	    #elif (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WEP_104)
	        #if defined(STACK_USE_UART)
	        	putrsUART("Set Security (WEP104)\r\n");
	        #endif	//#if defined(STACK_USE_UART)
	    #elif MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA_WITH_KEY 
	        #if defined(STACK_USE_UART)
	        	putrsUART("Set Security (WPA with key)\r\n");
	        #endif	//#if defined(STACK_USE_UART)
	    #elif MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA2_WITH_KEY 
	        #if defined(STACK_USE_UART)
	        	putrsUART("Set Security (WPA2 with key)\r\n");
	        #endif	//#if defined(STACK_USE_UART)
	    #elif MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA_WITH_PASS_PHRASE
	        #if defined(STACK_USE_UART)
	        	putrsUART("Set Security (WPA with pass phrase)\r\n");
	        #endif	//#if defined(STACK_USE_UART)
	    #elif MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA2_WITH_PASS_PHRASE
	        #if defined(STACK_USE_UART)
	        	putrsUART("Set Security (WPA2 with pass phrase)\r\n");    
	        #endif	//#if defined(STACK_USE_UART)
	    #elif MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA_AUTO_WITH_KEY
	        #if defined(STACK_USE_UART)
	        	putrsUART("Set Security (WPA with key, auto-select)\r\n");
	        #endif	//#if defined(STACK_USE_UART)
	    #elif MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA_AUTO_WITH_PASS_PHRASE
	        #if defined(STACK_USE_UART)
	        	putrsUART("Set Security (WPA with pass phrase, auto-select)\r\n");
	        #endif	//#if defined(STACK_USE_UART)
	    #endif	//#if (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_OPEN)
	
	    WF_CPSetSecurity(ConnectionProfileID,
	                     AppConfig.SecurityMode,
	                     AppConfig.WepKeyIndex,   /* only used if WEP enabled */
	                     AppConfig.SecurityKey,
	                     AppConfig.SecurityKeyLength);
	    #if defined(STACK_USE_UART)                     
	    	putrsUART("Start WiFi Connect\r\n");        
	    #endif	//#if defined(STACK_USE_UART)
	    WF_CMConnect(ConnectionProfileID);
	}
	//end WF_Connect
#endif	//#if defined(WF_CS_TRIS)


/******************************************************************************
 Function:        	void DisplayIPValue (IP_ADDR IPVal)
 Precondition:    	None
 Input:           	IP_ADDR IPVal
 Output:         	None
 Side Effects:    	None
 Description:       Writes an IP address to the LCD display and the UART as available
 *****************************************************************************/
void DisplayIPValue (IP_ADDR IPVal)
{
	//	printf("%u.%u.%u.%u", IPVal.v[0], IPVal.v[1], IPVal.v[2], IPVal.v[3]);
	#if defined (__dsPIC33E__) || defined (__PIC24E__)
		//Needs to be declared as static to avoid the array getting optimized by C30 v3.30 compiler for dsPIC33E/PIC24E. 
		//Otherwise the LCD displays corrupted IP address on Explorer 16. To be fixed in the future compiler release
		static BYTE IPDigit[4];    					
	#else
	    BYTE IPDigit[4];
	#endif	//#if defined (__dsPIC33E__) || defined (__PIC24E__)
		BYTE i;
	#ifdef USE_LCD
		BYTE j;
		BYTE LCDPos=16;
	#endif	//#ifdef USE_LCD

	for(i = 0; i < sizeof(IP_ADDR); i++)
	{
	    uitoa((WORD)IPVal.v[i], IPDigit);

		#if defined(STACK_USE_UART)
			putsUART((char *) IPDigit);
		#endif	//#if defined(STACK_USE_UART)

		#ifdef USE_LCD
			for(j = 0; j < strlen((char*)IPDigit); j++)
			{
				LCDText[LCDPos++] = IPDigit[j];
			}
			if(i == sizeof(IP_ADDR)-1)
				break;
			LCDText[LCDPos++] = '.';
		#else
			if(i == sizeof(IP_ADDR)-1)
				break;
		#endif	//#ifdef USE_LCD

		#if defined(STACK_USE_UART)
			while(BusyUART());
			WriteUART('.');
		#endif	//#if defined(STACK_USE_UART)
	}

	#ifdef USE_LCD
		if(LCDPos < 32u)
			LCDText[LCDPos] = 0;
		LCDUpdate();
	#endif	//#ifdef USE_LCD
}
//end DisplayIPValue

//========== end explorer16_service.c ==========
