/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        adc_service.c
 * Dependencies:    See INCLUDES section below
 * Processor:       dsPIC33
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:
*/

//Includes
#include "include files.h"


//Fuses


//Variables


//Private Prototypes
 

//Declarations

/******************************************************************************
 Function:        	void Adc_Initialization_Service (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       Initialize ADC module.
 *****************************************************************************/
void Adc_Initialization_Service (void)
{

	ADC_DIGITAL_MODE();
	ADC_CHANNEL_0_CONFIGURATION = 0x0000;	//set channel 0 to default values
	ADC_CHANNEL_123_CONFIGURATION = 0x0000;	//set channels 1,2 & 3 to default values
	ADC_10_12_BIT_OPERATION = CLEAR;		//set to 10 bit operation
	ADC_SYSTEM_CLOCK_OFF();					//manual conversion
	ADC_NO_SCANNING();						//no scanning
	ADC_CONVERSION_CLOCK_SOURCE = CLEAR;	//set ADC clock source to use system clock (Tcy)
	ADC_SAMPLE_CLOCK_PERIOD();				//set sampling time
	ADC_CONVERSION_CLOCK_PERIOD();			//set conversion time
	ADC_VDD_VSS_1_CONVERSION();				//set voltage reference as Vref+ pin and AVss
											//set interrupt flag after 1 conversion
	ADC_INTERRUPT_ENABLE = CLEAR;			//disable ADC interrupt
	ADC_INTERRUPT_FLAG = CLEAR;				//clear the flag
	ADC_INTERRUPT_PRIORITY = 0;				//set interrupt priority to low
	//ADC_INTERRUPT_STATUS_FLAG = CLEAR;		//clear status flag

}
//end Adc_Initialization_Service


/******************************************************************************
 Function:        	unsigned int Adc_Service (unsigned char adc_channel)
 Precondition:    	GPIO ports are assigned to ANx port(s) using the
 					GPIO_PORT_IS (gpio_port, port_assignment) function.
 Input:           	ADC Channel
 Output:         	Raw ADC value
 Side Effects:    	The C30 library functions are not used to reduce latentcy.
 Description:       General ADC service functions.
 *****************************************************************************/
unsigned int Adc_Service (unsigned char adc_channel)
{
	unsigned int adc_result;
	
	switch (adc_channel)
	{
		case ADC_CHANNEL_0:
			ADC_PORT_CONFIGURATION = ADC_0_ON;
			ADC_CHANNEL_0_CONFIGURATION = 0x0000;
			break;
		case ADC_CHANNEL_1:		
			ADC_CHANNEL_0_CONFIGURATION = 0x0001;
			ADC_PORT_CONFIGURATION = ADC_1_ON;
			break;
		case ADC_CHANNEL_2:
			ADC_CHANNEL_0_CONFIGURATION = 0x0002;
			ADC_PORT_CONFIGURATION = ADC_2_ON;
			break;
		case ADC_CHANNEL_3:
			ADC_CHANNEL_0_CONFIGURATION = 0x0003;
			ADC_PORT_CONFIGURATION = ADC_3_ON;
			break;
		case ADC_CHANNEL_4:
			ADC_CHANNEL_0_CONFIGURATION = 0x0004;
			ADC_PORT_CONFIGURATION = ADC_4_ON;
			break;
		case ADC_CHANNEL_5:
			ADC_CHANNEL_0_CONFIGURATION = 0x0005;
			ADC_PORT_CONFIGURATION = ADC_5_ON;
			break;
		default:
			break;
	}
	adc_result = Adc_Read_Service ();	//read ADC data
	ADC_DIGITAL_MODE();					//set I/O to digital inputs
	return adc_result;
}
//end Adc_Service


/******************************************************************************
 Function:        	unsigned int Adc_Read_Service (void)
 Precondition:    	None
 Input:           	None
 Output:         	Raw ADC value
 Side Effects:    	The C30 library functions are not used to reduce latentcy.
 Description:       Read ADC service.
 *****************************************************************************/
unsigned int Adc_Read_Service (void)
{
	unsigned char index1;
	
	//manual sample mode
	ADC_MANUAL_SAMPLE_MODE();			
	//turn on ADC
	ADC_RUN_MODE = ON;
	//enable manual sampling				
	ADC_SAMPLE_ENABLE = SET;
	//the following Nops help the sampling, adjust as required
	for (index1 = 0; index1 <= 100; index1++)
		Nop();
	//disable sampling
	ADC_SAMPLE_ENABLE = CLEAR;
	//check if conversion is done
	while (ADC_CONVERSION_STATUS == CLEAR);	
	//turn off the ADC				
	ADC_RUN_MODE = OFF;
	//return ADC result
	return ADC1BUF0;
}
//end Adc_Read_Service

//========== end ascii_service.c ==========
