/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        application_service.c
 * Dependencies:    See INCLUDES section below
 * Processor:       dsPIC33
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:
*/

//Includes
#include "include files.h"


//Fuses


//Variables


//Private Prototypes
 

//Declarations


/******************************************************************************
 Function:        	void Process_Io (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
void Process_Io (void)
{
	static DWORD t = 0;
	//VendingMachine ();
	//Perform timer tasks (every second).
	if(TickGet() - t >= TICK_SECOND/2ul)
	{
		if (BUTTON2_IO == FALSE)
		{
			DelayMs(10);
			if (BUTTON2_IO == FALSE)
				Measure_Temperature ();
		}
		if (BUTTON3_IO == FALSE)
		{
			DelayMs(10);
			if (BUTTON3_IO == FALSE)
				Measure_Pot_Voltage ();
		}
	    t = TickGet();
	    LED0_IO ^= 1;
	}
}
//end ProcessIO


/******************************************************************************
 Function:        	void Measure_Pot_Voltage (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
 void Measure_Pot_Voltage (void)
 {
 	unsigned char index1;
	float temp_reg1;
	int temp_reg2;
	char temp_reg3;
	char temp_reg4;
	char temp_reg5;
	char temp_reg6;
	int adc_result;
	char adc_result_lb;
	char adc_result_hb;
	char *buffer_pointer;
	
	for (index1 = 0; index1 <= 15; index1 ++)
		VOLTAGE [index1] = NULL;
	adc_result = Adc_Service (ADC_CHANNEL_5);
	temp_reg1 = (float)adc_result / (float)1024;
	temp_reg1 *= (float)3300;
	temp_reg2 = (int)temp_reg1;
	temp_reg3 =  temp_reg2 / 1000;	//thousands
	temp_reg4 = (temp_reg2 - (temp_reg3 * 1000)) / 100;	//hundreds
	temp_reg5 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) / 10;	//tens
	temp_reg6 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) - (temp_reg5 * 10);	//ones
	adc_result_hb = temp_reg3;
	adc_result_hb <<= 4;
	adc_result_hb |= temp_reg4;
	buffer_pointer = Convert_Hex_to_Ascii (adc_result_hb);
	VOLTAGE [0] = *(buffer_pointer + 0);
	VOLTAGE [1] = *(buffer_pointer + 1);
	adc_result_lb =  temp_reg5;
	adc_result_lb <<= 4;
	adc_result_lb |= temp_reg6;
	buffer_pointer = Convert_Hex_to_Ascii (adc_result_lb);
	VOLTAGE [2] = *(buffer_pointer + 0);
	VOLTAGE [3] = *(buffer_pointer + 1);
	VOLTAGE [4] = 0x6d;
	VOLTAGE [5] = 0x56;
	#if defined(USE_LCD)
		strcpypgm2ram((char*)LCDText, VOLTAGE);
		LCDUpdate();
	#endif
}
//end Measure_Pot_Voltage

/******************************************************************************
 Function:        	void Measure_Temperature (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
 void Measure_Temperature (void)
 {
 	unsigned char index1;
	float temp_reg1;
	int temp_reg2;
	char temp_reg3;
	char temp_reg4;
	char temp_reg5;
	char temp_reg6;
	int adc_result;
	char adc_result_lb;
	char adc_result_hb;
	char *buffer_pointer;
	
	for (index1 = 0; index1 <= 15; index1 ++)
		TEMPERATURE [index1] = NULL;
	adc_result = Adc_Service (ADC_CHANNEL_4);
	temp_reg1 = (float)adc_result / (float)1024;
	temp_reg1 = ((temp_reg1 * (float)3300) - (float)500) / (float)10;
	temp_reg2 = (int)temp_reg1;
	temp_reg3 =  temp_reg2 / 1000;	//thousands
	temp_reg4 = (temp_reg2 - (temp_reg3 * 1000)) / 100;	//hundreds
	temp_reg5 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) / 10;	//tens
	temp_reg6 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) - (temp_reg5 * 10);	//ones
	adc_result_hb = temp_reg3;
	adc_result_hb <<= 4;
	adc_result_hb |= temp_reg4;
	buffer_pointer = Convert_Hex_to_Ascii (adc_result_hb);
	TEMPERATURE [0] = *(buffer_pointer + 0);
	TEMPERATURE [1] = *(buffer_pointer + 1);
	if (TEMPERATURE [0] == '0')
		TEMPERATURE [0] = 0x20;
	if (TEMPERATURE [1] == '0')
		TEMPERATURE [1] = 0x20;
	adc_result_lb =  temp_reg5;
	adc_result_lb <<= 4;
	adc_result_lb |= temp_reg6;
	buffer_pointer = Convert_Hex_to_Ascii (adc_result_lb);
	TEMPERATURE [2] = *(buffer_pointer + 0);
	TEMPERATURE [3] = *(buffer_pointer + 1);
	if (TEMPERATURE [2] == '0')
		TEMPERATURE [2] = 0x20;
	if (TEMPERATURE [3] == '0')
		TEMPERATURE [3] = 0x30;
	TEMPERATURE [4] = 0x64;
	TEMPERATURE [5] = 0x65;
	TEMPERATURE [6] = 0x67;
	TEMPERATURE [7] = 0x2d;
	TEMPERATURE [8] = 0x43;
	#if defined(USE_LCD)
		strcpypgm2ram((char*)LCDText, TEMPERATURE);
		LCDUpdate();
	#endif
}
//end Measure_Temperature

//========== end application_service.c ==========
