/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        global_variables.h
 * Dependencies:    See INCLUDES section below
 * Processor:       dsPIC33
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:
*/

#ifndef _GLOBAL_VARIABLES_H
	#define _GLOBAL_VARIABLES_H
	
	#include "TCPIP Stack/TCPIP.h"
	// MAC Address Serialization using a MPLAB PM3 Programmer and 
	// Serialized Quick Turn Programming (SQTP). 
	// The advantage of using SQTP for programming the MAC Address is it
	// allows you to auto-increment the MAC address without recompiling 
	// the code for each unit.  To use SQTP, the MAC address must be fixed
	// at a specific location in program memory.  Uncomment these two pragmas
	// that locate the MAC address at 0x1FFF0.  Syntax below is for MPLAB C 
	// Compiler for PIC18 MCUs. Syntax will vary for other compilers.
	//#pragma romdata MACROM=0x1FFF0
	static ROM BYTE SerializedMACAddress[6] = {MY_DEFAULT_MAC_BYTE1, MY_DEFAULT_MAC_BYTE2, MY_DEFAULT_MAC_BYTE3, MY_DEFAULT_MAC_BYTE4, MY_DEFAULT_MAC_BYTE5, MY_DEFAULT_MAC_BYTE6};
	//#pragma romdata
	
	// Define a header structure for validating the AppConfig data structure in EEPROM/Flash
	typedef struct
	{
		unsigned short wConfigurationLength;	// Number of bytes saved in EEPROM/Flash (sizeof(APP_CONFIG))
		unsigned short wOriginalChecksum;		// Checksum of the original AppConfig defaults as loaded from ROM (to detect when to wipe the EEPROM/Flash record of AppConfig due to a stack change, such as when switching from Ethernet to Wi-Fi)
		unsigned short wCurrentChecksum;		// Checksum of the current EEPROM/Flash data.  This protects against using corrupt values if power failure occurs while writing them and helps detect coding errors in which some other task writes to the EEPROM in the AppConfig area.
	} NVM_VALIDATION_STRUCT;
	
	
	typedef struct _VEND_ITEM
	{
		BYTE name[11];
		BYTE stock;
		BYTE price;
	}VEND_ITEM;
	
	extern VEND_ITEM	Products[];		// All items in the machine
	extern BYTE			machineDesc[];			// Machine description string
	extern BYTE 		curItem;					// Current product being displayed
	extern BYTE 		curCredit;					// Current deposit credit, as number of $0.25 quarters
	
	extern int			smVend;
	
	extern unsigned char STRING_ARRAY [];
	extern unsigned char TEMPERATURE [];
	extern unsigned char VOLTAGE [];
	
	//Declare AppConfig structure and some other supporting stack variables
	extern APP_CONFIG AppConfig;
	//Checksum of the ROM defaults for AppConfig
	extern unsigned short wOriginalAppConfigChecksum;	
	extern BYTE AN0String [8];
	
	#if defined(STACK_USE_HTTP2_SERVER)
		//Sticky status message variable.
		//This is used to indicated whether or not the previous POST operation was 
		//successful.  The application uses these to store status messages when a 
		//POST operation redirects.  This lets the application provide status messages
		//after a redirect, when connection instance data has already been lost.
		extern BOOL lastSuccess;
		
		//Stick status message variable.  See lastSuccess for details.
		extern BOOL lastFailure;
	#endif
	
#endif
/*
#if defined(STACK_USE_GENERIC_TCP_CLIENT_EXAMPLE)
	// Defines the server to be accessed for this application
	//static BYTE ServerName[] =	"www.Lab4.local";
	extern BYTE ServerName[];
	// Defines the port to be accessed for this application
	extern WORD ServerPort;
	// Defines the URL to be requested by this HTTP client
	//static ROM BYTE RemoteURL[] = "/Lab4/";
	extern ROM BYTE RemoteURL[];
#endif
*/
