/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        main.c
 * Dependencies:    See INCLUDES section below
 * Processor:       dsPIC33
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:
*/

//Includes
#include "TCPIP Stack/TCPIP.h"

#if defined(STACK_USE_ZEROCONF_LINK_LOCAL)
	#include "TCPIP Stack/ZeroconfLinkLocal.h"
#endif	//#if defined(STACK_USE_ZEROCONF_LINK_LOCAL)

#if defined(STACK_USE_ZEROCONF_MDNS_SD)
	#include "TCPIP Stack/ZeroconfMulticastDNS.h"
#endif	//#if defined(STACK_USE_ZEROCONF_MDNS_SD)

//Fuses


//Variables


//Private Prototypes
 

//Declarations


/*
* This macro uniquely defines this file as the main entry point.
* There should only be one such definition in the entire project,
* and this file must define the AppConfig variable as described below.
*/
#define THIS_IS_STACK_APPLICATION


// Use UART2 instead of UART1 for stdout (printf functions).  Explorer 16 
// serial port hardware is on PIC UART2 module.
#if defined(EXPLORER_16) || defined(PIC24FJ256DA210_DEV_BOARD)
	int __C30_UART = 2;
#endif	//#if defined(EXPLORER_16) || defined(PIC24FJ256DA210_DEV_BOARD)

#include "include files.h"


// C30 Exception Handlers
// If your code gets here, you either tried to read or write
// a NULL pointer, or your application overflowed the stack
// by having too many local variables or parameters declared.
void _ISR __attribute__((__no_auto_psv__)) _AddressError(void)
{
    Nop();
	Nop();
}
void _ISR __attribute__((__no_auto_psv__)) _StackError(void)
{
    Nop();
	Nop();
}

/******************************************************************************
 Function:        	int main (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       Main application entry point.
 *****************************************************************************/
int main (void)
{
	Initialization_Service ();
	// Now that all items are initialized, begin the co-operative
	// multitasking loop.  This infinite loop will continuously 
	// execute all stack-related tasks, as well as your own
	// application's functions.  Custom functions should be added
	// at the end of this loop.
    // Note that this is a "co-operative mult-tasking" mechanism
    // where every task performs its tasks (whether all in one shot
    // or part of it) and returns so that other tasks can do their
    // job.
    // If a task needs very long time to do its job, it must be broken
    // down into smaller pieces so that other tasks can have CPU time.
    while(TRUE)
	{
		//#if defined(STACK_USE_HTTP2_SERVER)
			Stack_Service ();
		//#endif	//#if defined(STACK_USE_HTTP2_SERVER)
		
		//#if defined(STACK_USE_GENERIC_TCP_CLIENT_EXAMPLE)
			//void Tcp_Client_Service (void);
		//#endif	//#if defined(STACK_USE_GENERIC_TCP_CLIENT_EXAMPLE)
		
		Process_Io ();
	}
}
//end main

//========== end main.c ==========
